@@ -106,7 +106,7 @@ var subprocess_callbacks = {};
 function spawn_async(args, callback) {
     subprocess_id++;
     subprocess_callbacks[subprocess_id] = callback;
-    spawn(new Array("cinnamon-subprocess-wrapper", subprocess_id.toString()).concat(args));
+    spawn(["cinnamon-subprocess-wrapper", subprocess_id.toString(), ...args]);
 }
 
 /**
@@ -365,7 +365,7 @@ const _LATINISE_REGEX = {
     IJ: /\u0132/g,
     J: /[\u012E\u0134]/g,
     K: /\u0136/g,
-    L: /[\u0139\u013B\u013D\u0130F\u0141]/g,
+    L: /[\u0139\u013B\u013D\u013F\u0141]/g,
     N: /[\xD1\u0143\u0145\u0147\u014A]/g,
     O: /[\xD2-\xD6\xD8\u014C\u014E\u0150]/g,
     OE: /\u0152/g,
@@ -734,7 +734,7 @@ function getGObjectPropertyValues(obj, r = 0) {
     let baseInfo = repository.find_by_gtype(obj.constructor.$gtype);
     let propertyNames = [];
     for (let info = baseInfo; info !== null; info = Gir.object_info_get_parent(info)) {
-        propertyNames = propertyNames.concat(_getWritablePropertyNamesForObjectInfo(info));
+        propertyNames = [...propertyNames, ..._getWritablePropertyNamesForObjectInfo(info)];
     }
     if (r > 0 && propertyNames.length === 0) {
         return obj.toString();
@@ -754,3 +754,31 @@ function getGObjectPropertyValues(obj, r = 0) {
     }
     return jsRepresentation;
 }
+
+function version_exceeds(version, min_version) {
+    let our_version = version.split(".");
+    let cmp_version = min_version.split(".");
+    let i;
+
+    for (i = 0; i < our_version.length && i < cmp_version.length; i++) {
+        let our_part = parseInt(our_version[i]);
+        let cmp_part = parseInt(cmp_version[i]);
+
+        if (isNaN(our_part) || isNaN(cmp_part)) {
+            return false;
+        }
+
+        if (our_part < cmp_part) {
+            return false;
+        } else
+        if (our_part > cmp_part) {
+            return true;
+        }
+    }
+
+    if (our_version.length < cmp_version.length) {
+        return false;
+    } else {
+        return true;
+    }
+}
